@@ -5,7 +5,7 @@ from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional
 
-from pydantic import AnyHttpUrl, BaseModel, Field, stricturl
+from pydantic import AnyHttpUrl, BaseModel, Extra, Field, stricturl
 
 from .types import MessageDispatchEnum, MessageTypeEnum
 
@@ -486,37 +486,32 @@ class ChannelConfig(BaseModel):
 class ResultFieldSchema(BaseModel):
     class Config:
         validate_assignment = True
+        extra = Extra.forbid
 
     status: bool = Field(
         True,
         title="Status",
         description="Call result status.",
     )
-    msg_id: str = Field(
-        "SUCCESS",
+    id: str = Field(
+        ...,
         max_length=32,
-        title="Message ID",
+        title="Result ID",
         description="Result message ID in Daschat.",
         example="SUCCESS",
     )
-    text: str = Field(
-        "Success",
-        max_length=255,
-        title="Result message",
-        description="Result text message or text template message.",
-        example="Message sent",
-    )
     params: dict = Field(
         {},
         title="Params",
-        description="Params for the result template message.",
-        example="",
+        description="Params for the result message.",
+        example={"user": "theusername"},
     )
 
 
 class DispatchCallOutSchema(BaseModel):
     class Config:
         validate_assignment = True
+        extra = Extra.forbid
 
     result: ResultFieldSchema = Field(
         ...,
